@@ -1,6 +1,10 @@
 #include <git2.h>
 #include <Rinternals.h>
 
+#ifndef GIT_OBJECT_COMMIT
+#define GIT_OBJECT_COMMIT GIT_OBJ_COMMIT
+#endif
+
 void warn_last_msg();
 void bail_if(int err, const char *what);
 void bail_if_null(void * ptr, const char * what);
@@ -10,6 +14,7 @@ SEXP safe_char(const char *x);
 SEXP make_strvec(int n, ...);
 SEXP build_list(int n, ...);
 SEXP list_to_tibble(SEXP df);
+SEXP new_git_repository(git_repository *repo);
 git_repository *get_git_repository(SEXP ptr);
 git_object *resolve_refish(SEXP string, git_repository *repo);
 git_commit *ref_to_commit(SEXP ref, git_repository *repo);
@@ -18,14 +23,4 @@ git_commit *ref_to_commit(SEXP ref, git_repository *repo);
 
 #define AT_LEAST_LIBGIT2(x,y) (LIBGIT2_VER_MAJOR > x || LIBGIT2_VER_MINOR >= y)
 
-/* Some compatibility macros */
-#if !AT_LEAST_LIBGIT2(0, 22)
-#define git_remote_lookup(a,b,c) git_remote_load(a,b,c)
-#endif
-
-#if ! AT_LEAST_LIBGIT2(0, 21)
-#define git_checkout_options git_checkout_opts
-#define GIT_CHECKOUT_OPTIONS_INIT GIT_CHECKOUT_OPTS_INIT
-#endif
-
 void set_checkout_notify_cb(git_checkout_options *opts);
